# Pogmake

Peterino's cross platform make replacement and automation tooler.

I'm just putting this on Pypi because I hate having to git clone this repo around so much.

Doing a big boy release in mid Feb.

Documentation available here:

[Pogmake Documentation](https://pogmake.readthedocs.io/en/latest/)

## Quickstart

`pip install pogmake`

`pog --list` - to show all jobs or `pog --init` to create a sample starter file

